pandas.DataFrame
================

.. currentmodule:: pandas

.. autoclass:: DataFrame

   


..
   HACK -- the point here is that we don't want this to appear in the output, but the autosummary should still generate the pages.
   .. autosummary::
      :toctree:
      
      DataFrame.abs
      DataFrame.add
      DataFrame.add_prefix
      DataFrame.add_suffix
      DataFrame.align
      DataFrame.all
      DataFrame.any
      DataFrame.append
      DataFrame.apply
      DataFrame.applymap
      DataFrame.as_blocks
      DataFrame.as_matrix
      DataFrame.asfreq
      DataFrame.astype
      DataFrame.at_time
      DataFrame.between_time
      DataFrame.bfill
      DataFrame.bool
      DataFrame.boxplot
      DataFrame.clip
      DataFrame.clip_lower
      DataFrame.clip_upper
      DataFrame.combine
      DataFrame.combineAdd
      DataFrame.combineMult
      DataFrame.combine_first
      DataFrame.compound
      DataFrame.consolidate
      DataFrame.convert_objects
      DataFrame.copy
      DataFrame.corr
      DataFrame.corrwith
      DataFrame.count
      DataFrame.cov
      DataFrame.cummax
      DataFrame.cummin
      DataFrame.cumprod
      DataFrame.cumsum
      DataFrame.delevel
      DataFrame.describe
      DataFrame.diff
      DataFrame.div
      DataFrame.divide
      DataFrame.dot
      DataFrame.drop
      DataFrame.drop_duplicates
      DataFrame.dropna
      DataFrame.duplicated
      DataFrame.eq
      DataFrame.eval
      DataFrame.ffill
      DataFrame.fillna
      DataFrame.filter
      DataFrame.first
      DataFrame.first_valid_index
      DataFrame.floordiv
      DataFrame.from_csv
      DataFrame.from_dict
      DataFrame.from_items
      DataFrame.from_records
      DataFrame.ge
      DataFrame.get
      DataFrame.get_dtype_counts
      DataFrame.get_ftype_counts
      DataFrame.get_value
      DataFrame.get_values
      DataFrame.groupby
      DataFrame.gt
      DataFrame.head
      DataFrame.hist
      DataFrame.icol
      DataFrame.idxmax
      DataFrame.idxmin
      DataFrame.iget_value
      DataFrame.info
      DataFrame.insert
      DataFrame.interpolate
      DataFrame.irow
      DataFrame.isin
      DataFrame.isnull
      DataFrame.iteritems
      DataFrame.iterkv
      DataFrame.iterrows
      DataFrame.itertuples
      DataFrame.join
      DataFrame.keys
      DataFrame.kurt
      DataFrame.kurtosis
      DataFrame.last
      DataFrame.last_valid_index
      DataFrame.le
      DataFrame.load
      DataFrame.lookup
      DataFrame.lt
      DataFrame.mad
      DataFrame.mask
      DataFrame.max
      DataFrame.mean
      DataFrame.median
      DataFrame.merge
      DataFrame.min
      DataFrame.mod
      DataFrame.mode
      DataFrame.mul
      DataFrame.multiply
      DataFrame.ne
      DataFrame.notnull
      DataFrame.pct_change
      DataFrame.pivot
      DataFrame.pivot_table
      DataFrame.plot
      DataFrame.pop
      DataFrame.pow
      DataFrame.prod
      DataFrame.product
      DataFrame.quantile
      DataFrame.query
      DataFrame.radd
      DataFrame.rank
      DataFrame.rdiv
      DataFrame.reindex
      DataFrame.reindex_axis
      DataFrame.reindex_like
      DataFrame.rename
      DataFrame.rename_axis
      DataFrame.reorder_levels
      DataFrame.replace
      DataFrame.resample
      DataFrame.reset_index
      DataFrame.rfloordiv
      DataFrame.rmod
      DataFrame.rmul
      DataFrame.rpow
      DataFrame.rsub
      DataFrame.rtruediv
      DataFrame.save
      DataFrame.select
      DataFrame.set_index
      DataFrame.set_value
      DataFrame.shift
      DataFrame.skew
      DataFrame.sort
      DataFrame.sort_index
      DataFrame.sortlevel
      DataFrame.squeeze
      DataFrame.stack
      DataFrame.std
      DataFrame.sub
      DataFrame.subtract
      DataFrame.sum
      DataFrame.swapaxes
      DataFrame.swaplevel
      DataFrame.tail
      DataFrame.take
      DataFrame.to_clipboard
      DataFrame.to_csv
      DataFrame.to_dense
      DataFrame.to_dict
      DataFrame.to_excel
      DataFrame.to_gbq
      DataFrame.to_hdf
      DataFrame.to_html
      DataFrame.to_json
      DataFrame.to_latex
      DataFrame.to_msgpack
      DataFrame.to_panel
      DataFrame.to_period
      DataFrame.to_pickle
      DataFrame.to_records
      DataFrame.to_sparse
      DataFrame.to_sql
      DataFrame.to_stata
      DataFrame.to_string
      DataFrame.to_timestamp
      DataFrame.to_wide
      DataFrame.transpose
      DataFrame.truediv
      DataFrame.truncate
      DataFrame.tshift
      DataFrame.tz_convert
      DataFrame.tz_localize
      DataFrame.unstack
      DataFrame.update
      DataFrame.var
      DataFrame.where
      DataFrame.xs




   


..
   HACK -- the point here is that we don't want this to appear in the output, but the autosummary should still generate the pages.
   .. autosummary::
      :toctree:
      
      DataFrame.T
      DataFrame.at
      DataFrame.axes
      DataFrame.blocks
      DataFrame.dtypes
      DataFrame.empty
      DataFrame.ftypes
      DataFrame.iat
      DataFrame.iloc
      DataFrame.is_copy
      DataFrame.ix
      DataFrame.loc
      DataFrame.ndim
      DataFrame.shape
      DataFrame.values


